@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2012 Free Software Foundation, Inc.
+# Copyright (C) 2011-2013 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 # parallel-tests:
 #  - non-existent scripts listed in TESTS get diagnosed, even when
 #    all the $(TEST_LOGS) have a dummy dependency.
-# See also related test 'test-missing.test'.
+# See also related test 'test-missing.sh'.
 
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_OUTPUT
